// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KCMUTILS_VERSION_H
#define KCMUTILS_VERSION_H

#define KCMUTILS_VERSION_STRING "6.24.0"
#define KCMUTILS_VERSION_MAJOR 6
#define KCMUTILS_VERSION_MINOR 24
#define KCMUTILS_VERSION_PATCH 0
#define KCMUTILS_VERSION ((6<<16)|(24<<8)|(0))

#endif
